==> ?download=%2Fupload%2Fversions%2FDZIRCMS-2.2.0.zip: admin/includes/include.lay_new.php <==
<?php
/**
 * Project: 
 * Contenido Content Management System
 * 
 * Description: 
 * Link for "new layout"
 * 
 * Requirements: 
 * @con_php_req 5.0
 * 
 *
 * @package    Contenido Backend includes
 * @version    1.0.1
 * @author     Olaf Niemann
 * @copyright  four for business AG <www.4fb.de>
 * @license    http://www.contenido.org/license/LIZENZ.txt
 * @link       http://www.4fb.de
 * @link       http://www.contenido.org
 * @since      file available since contenido release <= 4.6
 * 
 * {@internal 
 *   created 2003-03-27
 *   modified 2008-06-27, Frederic Schneider, add security fix
 *
 *   $Id$:
 * }}
 * 
 */

if(!defined('CON_FRAMEWORK')) {
	die('Illegal call');
}

$oUser = new cApiUser($auth->auth["uid"]);
if (!isset($_REQUEST["elemperpage"]) || !is_numeric($_REQUEST['elemperpage']) || $_REQUEST['elemperpage'] < 0) {
	$_REQUEST["elemperpage"] = $oUser->getProperty("itemsperpage", $area);
}

$tpl->reset();

$str = '';
if ((int) $client > 0) {
    $str .= '<div style="height: 4.2em; padding-left: 4px; border-bottom: 1px solid #B3B3B3;">';
    $str .= '<a style="display: block; float: none; margin-top: .2em;" class="addfunction" target="right_bottom" href="'.$sess->url("main.php?area=lay_edit&frame=4&action=lay_new").'">'.i18n("New Layout").'</a>';
    $str .= '<a style="display: block; float: none; margin-top: 0;" class="syncmod" href="'.$sess->url($sess->self_url()."&synclay=1").'">';
    $str .= i18n("Sync all layouts").'</a>';
    $str .= '<div style="clear: both;"></div></div>';

    $actlink = 'actions';
    $oActionRow = new cFoldingRow('28cf9b31-e6d7-4657-a9a7-db31478e7a5c', i18n("Actions"), $actlink);
    $oActionRow->setContentData($str);
    
    $_REQUEST['page'] = ((isset($_REQUEST['page'])) ? (int) $_REQUEST['page'] : 1);
    
    ###############
    # List Options
    ###############
    $aSortByOptions = array("name" => i18n("Name"));
    $aSortOrderOptions = array("asc" => i18n("Ascending"), "desc" => i18n("Descending"));
    $_REQUEST['sortby'] = (((isset($_REQUEST['sortby'])) && (array_key_exists($_REQUEST['sortby'], $aSortByOptions))) ? $_REQUEST['sortby'] : '');
    $_REQUEST['sortorder'] = (((isset($_REQUEST['sortorder'])) && (array_key_exists($_REQUEST['sortorder'], $aSortOrderOptions))) ? $_REQUEST['sortorder'] : '');
    $listoplink="listoptions";
    $oListOptionRow = new cFoldingRow("e9ddf415-4b2d-4a75-8060-c3cd88b6ff98", i18n("List options"), $listoplink);
    $oSelectItemsPerPage = new cHTMLSelectElement("elemperpage");
    $oSelectItemsPerPage->autoFill(array(0 => i18n("-- All --"), 25 => 25, 50 => 50, 75 => 75, 100 => 100));
    $oSelectItemsPerPage->setDefault($_REQUEST["elemperpage"]);
    $oSelectSortBy = new cHTMLSelectElement("sortby");
    $oSelectSortBy->autoFill($aSortByOptions);
    $oSelectSortBy->setDefault($_REQUEST["sortby"]);
    $oSelectSortOrder = new cHTMLSelectElement("sortorder");
    $oSelectSortOrder->autoFill($aSortOrderOptions);
    $oSelectSortOrder->setDefault($_REQUEST["sortorder"]);

    $oSelectSearchIn = new cHTMLSelectElement("searchin");
    $oSelectSearchIn->autoFill(array('' => i18n("-- All --"), 
                                     'name' => i18n("Layoutname"), 
                                     'description' => i18n("Description"), 
                                     'code' => i18n("Code")));
                                     
    if (isset($_REQUEST["searchin"])) $oSelectSearchIn->setDefault($_REQUEST["searchin"]);

    $oTextboxFilter = new cHTMLTextbox("filter", stripslashes($_REQUEST["filter"]), 15);
    $content = '<div style="margin-bottom: 1px; border-bottom: 1px solid #B3B3B3;">';
    // Ye stuff will be done in javascript on apply button
    $content .= '<form action="javascript:execFilter(\''.$sess->id.'\');" id="filter" name="filter" method="get">';
    $content .= '<input type="hidden" name="area" value="lay">';
    $content .= '<input type="hidden" name="frame" value="1">';
    $content .= '<input type="hidden" name="contenido" value="'.$sess->id.'">';
    if (isset($_REQUEST["page"])) {
        $content .= '<input type="hidden" name="page" value="'.(int) $_REQUEST["page"].'">';
    }
    $content .= '<table>';
    $content .= '<tr>';
    $content .= '<td style="padding-left: 4px;" nowrap>'.i18n("Items / page").'</td>';
    $content .= '<td>'.$oSelectItemsPerPage->render().'</td>';
    $content .= '</tr>';
    $content .= '<tr>';
    $content .= '<td style="padding-left: 4px;">'.i18n("Sort by").'</td>';
    $content .= '<td>'.$oSelectSortBy->render().'</td>';
    $content .= '</tr>';
    $content .= '<tr>';
    $content .= '<td style="padding-left: 4px;">'.i18n("Sort order").'</td>';
    $content .= '<td>'.$oSelectSortOrder->render().'</td>';
    $content .= '</tr>';
    $content .= '<tr>';
    $content .= '<td style="padding-left: 4px;">'.i18n("Search for").'</td>';
    $content .= '<td>'.$oTextboxFilter->render().'</td>';
    $content .= '</tr>';
    $content .= '<td style="padding-left: 4px;">'.i18n("Search in").'</td>';
    $content .= '<td>'.$oSelectSearchIn->render().'</td>';
    $content .= '</tr>';
    $content .= '<tr>';
    $content .= '<td style="padding-left: 4px;">&nbsp;</td>';
    $content .= '<td><input type="submit" value="'.i18n("Apply").'"></td>';
    $content .= '</tr>';
    $content .= '</table>';
    $content .= '</form>';
    $content .= '</div>';
    $oListOptionRow->setContentData($content);

    #######
    # Pager & Sync Layout
    #######
    $oLayoutCollection	= new cApiLayoutCollection;
    $oLayoutCollection->setWhere("idclient", $client);

    $oLayoutCollection->query();
    $iItemCount = $oLayoutCollection->count();
    
    // sync all layouts if wanted
    if ((isset($_GET['synclay'])) && ((int) $_GET['synclay'] == 1)) {   
        
        /* @var $oLayout cApiModule */
        $aSyncedModules = array();
        while ($oLayout = $oLayoutCollection->next()) {
            if ($oLayout->get('code-orig') != $oLayout->get('code')) {

                # Track version
                $oVersion = new VersionLayout($oLayout->get('idlay'), $cfg, $cfgClient, $db, $client, $area, $frame);

                # Create new Layout Version in cms/version/layout/
                $oVersion->createNewVersion();

                # Synchronize the layout
                $oLayout->set("code", addslashes($oLayout->get('code')));
                $oLayout->set("lastmodified", date("Y-m-d H:i:s"));
                $oLayout->store();
                $aSyncedModules[] = $oLayout->get('name');
            }
        }
        if (count($aSyncedModules)) {
            sort($aSyncedModules);
            echo '<script>window.parent.parent.frames["right"].frames["right_bottom"].document.body.innerHTML = \'<div class="message">' . i18n("The following layouts were synchronized:") . '<br>' . implode('<br>', $aSyncedModules) . '</div>\';</script>';
            echo '<script>window.parent.frames["left_bottom"].document.location.href = window.parent.frames["left_bottom"].document.location.href;</script>';
        } else {
            echo '<script>window.parent.parent.frames["right"].frames["right_bottom"].document.body.innerHTML = \'<div class="message">' . i18n("All layouts already were synchronized") . '</div>\';</script>';
        }
    }    
    unset($oLayout, $oLayoutCollection);
    
    // pager
    $oPagerLink = new cHTMLLink;
    $pagerl="pagerlink";
    $oPagerLink->setTargetFrame('left_bottom');
    $oPagerLink->setLink("main.php");
    $oPagerLink->setCustom("elemperpage", $_REQUEST["elemperpage"]);
    $oPagerLink->setCustom("filter", stripslashes($_REQUEST["filter"]));
    $oPagerLink->setCustom("sortby", $_REQUEST["sortby"]);
    $oPagerLink->setCustom("sortorder", $_REQUEST["sortorder"]);
    $oPagerLink->setCustom("frame", 2);
    $oPagerLink->setCustom("area", $area);
    $oPagerLink->enableAutomaticParameterAppend();
    $oPagerLink->setCustom("contenido", $sess->id);
    $oPager = new cObjectPager("02420d6b-a77e-4a97-9395-7f6be480f497", $iItemCount, $_REQUEST["elemperpage"], $_REQUEST["page"], $oPagerLink, "page", $pagerl);

    $tpl->set('s', 'PAGINGLINK', $pagerl);
    $tpl->set('s', 'ACTION', '<table style="" border="0" cellspacing="0" cellpadding="0" width="100%">'.$oActionRow->render().$oListOptionRow->render().$oPager->render().'</table>');
    $tpl->set('s', 'ACTLINK', $actlink);
    $tpl->set('s', 'LISTOPLINK', $listoplink);
} else {
    $str .= '<div style="height: 2.5em; line-height: 2.5em; border: 1px solid #B3B3B3; padding-left: 4px;">'.i18n('No Client selected').'</div>';
    $tpl->set('s', 'PAGINGLINK', '');
    $tpl->set('s', 'ACTION', $str);
    $tpl->set('s', 'ACTLINK', '');
    $tpl->set('s', 'LISTOPLINK', '');
}

############################
# generate template
############################
$tpl->generate($cfg['path']['templates'] . $cfg['templates']['lay_left_top']);
?>

==> ?download=%2Fupload%2Fversions%2FDZIRCMS-2.3.2.zip: admin/includes/include.lay_new.php <==
<?php
/**
 * Project: 
 * Contenido Content Management System
 * 
 * Description: 
 * Link for "new layout"
 * 
 * Requirements: 
 * @con_php_req 5.0
 * 
 *
 * @package    Contenido Backend includes
 * @version    1.0.1
 * @author     Olaf Niemann
 * @copyright  four for business AG <www.4fb.de>
 * @license    http://www.contenido.org/license/LIZENZ.txt
 * @link       http://www.4fb.de
 * @link       http://www.contenido.org
 * @since      file available since contenido release <= 4.6
 * 
 * {@internal 
 *   created 2003-03-27
 *   modified 2008-06-27, Frederic Schneider, add security fix
 *
 *   $Id$:
 * }}
 * 
 */

if(!defined('CON_FRAMEWORK')) {
	die('Illegal call');
}

$oUser = new cApiUser($auth->auth["uid"]);
if (!isset($_REQUEST["elemperpage"]) || !is_numeric($_REQUEST['elemperpage']) || $_REQUEST['elemperpage'] < 0) {
	$_REQUEST["elemperpage"] = $oUser->getProperty("itemsperpage", $area);
}

$tpl->reset();

$str = '';
if ((int) $client > 0) {
    $str .= '<div style="height: 4.2em; padding-left: 4px; border-bottom: 1px solid #B3B3B3;">';
    $str .= '<a style="display: block; float: none; margin-top: .2em;" class="addfunction" target="right_bottom" href="'.$sess->url("main.php?area=lay_edit&frame=4&action=lay_new").'">'.i18n("New Layout").'</a>';
    $str .= '<a style="display: block; float: none; margin-top: 0;" class="syncmod" href="'.$sess->url($sess->self_url()."&synclay=1").'">';
    $str .= i18n("Sync all layouts").'</a>';
    $str .= '<div style="clear: both;"></div></div>';

    $actlink = 'actions';
    $oActionRow = new cFoldingRow('28cf9b31-e6d7-4657-a9a7-db31478e7a5c', i18n("Actions"), $actlink);
    $oActionRow->setContentData($str);
    
    $_REQUEST['page'] = ((isset($_REQUEST['page'])) ? (int) $_REQUEST['page'] : 1);
    
    ###############
    # List Options
    ###############
    $aSortByOptions = array("name" => i18n("Name"));
    $aSortOrderOptions = array("asc" => i18n("Ascending"), "desc" => i18n("Descending"));
    $_REQUEST['sortby'] = (((isset($_REQUEST['sortby'])) && (array_key_exists($_REQUEST['sortby'], $aSortByOptions))) ? $_REQUEST['sortby'] : '');
    $_REQUEST['sortorder'] = (((isset($_REQUEST['sortorder'])) && (array_key_exists($_REQUEST['sortorder'], $aSortOrderOptions))) ? $_REQUEST['sortorder'] : '');
    $listoplink="listoptions";
    $oListOptionRow = new cFoldingRow("e9ddf415-4b2d-4a75-8060-c3cd88b6ff98", i18n("List options"), $listoplink);
    $oSelectItemsPerPage = new cHTMLSelectElement("elemperpage");
    $oSelectItemsPerPage->autoFill(array(0 => i18n("-- All --"), 25 => 25, 50 => 50, 75 => 75, 100 => 100));
    $oSelectItemsPerPage->setDefault($_REQUEST["elemperpage"]);
    $oSelectSortBy = new cHTMLSelectElement("sortby");
    $oSelectSortBy->autoFill($aSortByOptions);
    $oSelectSortBy->setDefault($_REQUEST["sortby"]);
    $oSelectSortOrder = new cHTMLSelectElement("sortorder");
    $oSelectSortOrder->autoFill($aSortOrderOptions);
    $oSelectSortOrder->setDefault($_REQUEST["sortorder"]);

    $oSelectSearchIn = new cHTMLSelectElement("searchin");
    $oSelectSearchIn->autoFill(array('' => i18n("-- All --"), 
                                     'name' => i18n("Layoutname"), 
                                     'description' => i18n("Description"), 
                                     'code' => i18n("Code")));
                                     
    if (isset($_REQUEST["searchin"])) $oSelectSearchIn->setDefault($_REQUEST["searchin"]);

    $oTextboxFilter = new cHTMLTextbox("filter", stripslashes($_REQUEST["filter"]), 15);
    $content = '<div style="margin-bottom: 1px; border-bottom: 1px solid #B3B3B3;">';
    // Ye stuff will be done in javascript on apply button
    $content .= '<form action="javascript:execFilter(\''.$sess->id.'\');" id="filter" name="filter" method="get">';
    $content .= '<input type="hidden" name="area" value="lay">';
    $content .= '<input type="hidden" name="frame" value="1">';
    $content .= '<input type="hidden" name="contenido" value="'.$sess->id.'">';
    if (isset($_REQUEST["page"])) {
        $content .= '<input type="hidden" name="page" value="'.(int) $_REQUEST["page"].'">';
    }
    $content .= '<table>';
    $content .= '<tr>';
    $content .= '<td style="padding-left: 4px;" nowrap>'.i18n("Items / page").'</td>';
    $content .= '<td>'.$oSelectItemsPerPage->render().'</td>';
    $content .= '</tr>';
    $content .= '<tr>';
    $content .= '<td style="padding-left: 4px;">'.i18n("Sort by").'</td>';
    $content .= '<td>'.$oSelectSortBy->render().'</td>';
    $content .= '</tr>';
    $content .= '<tr>';
    $content .= '<td style="padding-left: 4px;">'.i18n("Sort order").'</td>';
    $content .= '<td>'.$oSelectSortOrder->render().'</td>';
    $content .= '</tr>';
    $content .= '<tr>';
    $content .= '<td style="padding-left: 4px;">'.i18n("Search for").'</td>';
    $content .= '<td>'.$oTextboxFilter->render().'</td>';
    $content .= '</tr>';
    $content .= '<td style="padding-left: 4px;">'.i18n("Search in").'</td>';
    $content .= '<td>'.$oSelectSearchIn->render().'</td>';
    $content .= '</tr>';
    $content .= '<tr>';
    $content .= '<td style="padding-left: 4px;">&nbsp;</td>';
    $content .= '<td><input type="submit" value="'.i18n("Apply").'"></td>';
    $content .= '</tr>';
    $content .= '</table>';
    $content .= '</form>';
    $content .= '</div>';
    $oListOptionRow->setContentData($content);

    #######
    # Pager & Sync Layout
    #######
    $oLayoutCollection	= new cApiLayoutCollection;
    $oLayoutCollection->setWhere("idclient", $client);

    $oLayoutCollection->query();
    $iItemCount = $oLayoutCollection->count();
    
    // sync all layouts if wanted
    if ((isset($_GET['synclay'])) && ((int) $_GET['synclay'] == 1)) {   
        
        /* @var $oLayout cApiModule */
        $aSyncedModules = array();
        while ($oLayout = $oLayoutCollection->next()) {
            if ($oLayout->get('code-orig') != $oLayout->get('code')) {

                # Track version
                $oVersion = new VersionLayout($oLayout->get('idlay'), $cfg, $cfgClient, $db, $client, $area, $frame);

                # Create new Layout Version in cms/version/layout/
                $oVersion->createNewVersion();

                # Synchronize the layout
                $oLayout->set("code", $oLayout->get('code'));
                $oLayout->set("lastmodified", date("Y-m-d H:i:s"));
                $oLayout->store();
                $aSyncedModules[] = $oLayout->get('name');
            }
        }
        if (count($aSyncedModules)) {
            sort($aSyncedModules);
            echo '<script>window.parent.parent.frames["right"].frames["right_bottom"].document.body.innerHTML = \'<div class="message">' . i18n("The following layouts were synchronized:") . '<br>' . implode('<br>', $aSyncedModules) . '</div>\';</script>';
            echo '<script>window.parent.frames["left_bottom"].document.location.href = window.parent.frames["left_bottom"].document.location.href;</script>';
        } else {
            echo '<script>window.parent.parent.frames["right"].frames["right_bottom"].document.body.innerHTML = \'<div class="message">' . i18n("All layouts already were synchronized") . '</div>\';</script>';
        }
    }    
    unset($oLayout, $oLayoutCollection);
    
    // pager
    $oPagerLink = new cHTMLLink;
    $pagerl="pagerlink";
    $oPagerLink->setTargetFrame('left_bottom');
    $oPagerLink->setLink("main.php");
    $oPagerLink->setCustom("elemperpage", $_REQUEST["elemperpage"]);
    $oPagerLink->setCustom("filter", stripslashes($_REQUEST["filter"]));
    $oPagerLink->setCustom("sortby", $_REQUEST["sortby"]);
    $oPagerLink->setCustom("sortorder", $_REQUEST["sortorder"]);
    $oPagerLink->setCustom("frame", 2);
    $oPagerLink->setCustom("area", $area);
    $oPagerLink->enableAutomaticParameterAppend();
    $oPagerLink->setCustom("contenido", $sess->id);
    $oPager = new cObjectPager("02420d6b-a77e-4a97-9395-7f6be480f497", $iItemCount, $_REQUEST["elemperpage"], $_REQUEST["page"], $oPagerLink, "page", $pagerl);

    $tpl->set('s', 'PAGINGLINK', $pagerl);
    $tpl->set('s', 'ACTION', '<table style="" border="0" cellspacing="0" cellpadding="0" width="100%">'.$oActionRow->render().$oListOptionRow->render().$oPager->render().'</table>');
    $tpl->set('s', 'ACTLINK', $actlink);
    $tpl->set('s', 'LISTOPLINK', $listoplink);
} else {
    $str .= '<div style="height: 2.5em; line-height: 2.5em; border: 1px solid #B3B3B3; padding-left: 4px;">'.i18n('No Client selected').'</div>';
    $tpl->set('s', 'PAGINGLINK', '');
    $tpl->set('s', 'ACTION', $str);
    $tpl->set('s', 'ACTLINK', '');
    $tpl->set('s', 'LISTOPLINK', '');
}

############################
# generate template
############################
$tpl->generate($cfg['path']['templates'] . $cfg['templates']['lay_left_top']);
?>
